==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/lt_LT.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "Pagalba",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Admin" : "Administravimas",
    "No app name specified" : "Nenurodytas programos pavadinimas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "today" : "šiandien",
    "yesterday" : "vakar",
    "last month" : "praeitą mėnesį",
    "_%n month ago_::_%n months ago_" : ["Prieš %n mėnesį","Prieš %n mėnesius","Prieš %n mėnesių"],
    "last year" : "praeitais metais",
    "_%n hour ago_::_%n hours ago_" : ["Prieš %n valandą","Prieš %n valandas","Prieš %n valandų"],
    "_%n minute ago_::_%n minutes ago_" : ["prieš %n min.","Prieš % minutes","Prieš %n minučių"],
    "seconds ago" : "prieš sekundę",
    "web services under your control" : "jūsų valdomos web paslaugos",
    "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
    "App directory already exists" : "Programos aplankas jau egzistuoja",
    "Can't create app folder. Please fix permissions. %s" : "Nepavyksta sukurti aplanko. Prašome pataisyti leidimus. %s",
    "No source specified when installing app" : "Nenurodytas šaltinis diegiant programą",
    "No href specified when installing app from http" : "Nenurodytas href diegiant programą iš http",
    "No path specified when installing app from local file" : "Nenurodytas kelias diegiant programą iš vietinio failo",
    "Archives of type %s are not supported" : "%s tipo archyvai nepalaikomi",
    "Failed to open archive when installing app" : "Nepavyko atverti archyvo diegiant programą",
    "App does not provide an info.xml file" : "Programa nepateikia info.xml failo",
    "App can't be installed because of not allowed code in the App" : "Programa negali būti įdiegta, nes turi neleistiną kodą",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Programa negali būti įdiegta, nes yra nesuderinama su šia ownCloud versija",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Programa negali būti įdiegta, nes turi <shipped>true</shipped> žymę, kuri yra neleistina ne kartu platinamoms programoms",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Programa negali būti įdiegta, nes versija pateikta info.xml/version nesutampa su versija deklaruota programų saugykloje",
    "Application is not enabled" : "Programa neįjungta",
    "Authentication error" : "Autentikacijos klaida",
    "Token expired. Please reload page." : "Sesija baigėsi. Prašome perkrauti puslapį.",
    "%s enter the database username." : "%s įrašykite duombazės naudotojo vardą.",
    "%s enter the database name." : "%s įrašykite duombazės pavadinimą.",
    "%s you may not use dots in the database name" : "%s negalite naudoti taškų duombazės pavadinime",
    "Oracle connection could not be established" : "Nepavyko sukurti Oracle ryšio",
    "Oracle username and/or password not valid" : "Neteisingas Oracle naudotojo vardas ir/arba slaptažodis",
    "DB Error: \"%s\"" : "DB klaida: \"%s\"",
    "Offending command was: \"%s\"" : "Vykdyta komanda buvo: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Turite prisijungti su egzistuojančia paskyra arba su administratoriumi.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Vykdyta komanda buvo: \"%s\", name: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "Neteisingas PostgreSQL naudotojo vardas ir/arba slaptažodis",
    "Set an admin username." : "Nustatyti administratoriaus naudotojo vardą.",
    "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
    "%s shared »%s« with you" : "%s pasidalino »%s« su tavimi",
    "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
    "Apps" : "Programos",
    "A valid username must be provided" : "Vartotojo vardas turi būti tinkamas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/lt_LT.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Negalima rašyti į \"config\" aplanką!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tai gali būti ištaisyta suteikiant web serveriui rašymo teises į config aplanką",
    "See %s" : "Žiūrėk %s",
    "Sample configuration detected" : "Aptiktas konfigūracijos pavyzdys",
    "PHP %s or higher is required." : "Reikalinga PHP %s arba aukštesnė.",
    "Following databases are supported: %s" : "Palaikomos duomenų bazės: %s",
    "Help" : "Pagalba",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Admin" : "Administravimas",
    "No app name specified" : "Nenurodytas programos pavadinimas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "today" : "šiandien",
    "yesterday" : "vakar",
    "last month" : "praeitą mėnesį",
    "_%n month ago_::_%n months ago_" : ["Prieš %n mėnesį","Prieš %n mėnesius","Prieš %n mėnesių"],
    "last year" : "praeitais metais",
    "_%n hour ago_::_%n hours ago_" : ["Prieš %n valandą","Prieš %n valandas","Prieš %n valandų"],
    "_%n minute ago_::_%n minutes ago_" : ["prieš %n min.","Prieš % minutes","Prieš %n minučių"],
    "seconds ago" : "prieš sekundę",
    "web services under your control" : "jūsų valdomos web paslaugos",
    "Empty filename is not allowed" : "Tuščias failo pavadinimas neleidžiamas",
    "File name is a reserved word" : "Failo pavadinimas negalimas, žodis rezervuotas",
    "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
    "App directory already exists" : "Programos aplankas jau egzistuoja",
    "Can't create app folder. Please fix permissions. %s" : "Nepavyksta sukurti aplanko. Prašome pataisyti leidimus. %s",
    "No source specified when installing app" : "Nenurodytas šaltinis diegiant programą",
    "No href specified when installing app from http" : "Nenurodytas href diegiant programą iš http",
    "No path specified when installing app from local file" : "Nenurodytas kelias diegiant programą iš vietinio failo",
    "Archives of type %s are not supported" : "%s tipo archyvai nepalaikomi",
    "Failed to open archive when installing app" : "Nepavyko atverti archyvo diegiant programą",
    "App does not provide an info.xml file" : "Programa nepateikia info.xml failo",
    "App can't be installed because of not allowed code in the App" : "Programa negali būti įdiegta, nes turi neleistiną kodą",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Programa negali būti įdiegta, nes yra nesuderinama su šia ownCloud versija",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Programa negali būti įdiegta, nes turi <shipped>true</shipped> žymę, kuri yra neleistina ne kartu platinamoms programoms",
    "Application is not enabled" : "Programa neįjungta",
    "Authentication error" : "Autentikacijos klaida",
    "Token expired. Please reload page." : "Sesija baigėsi. Prašome perkrauti puslapį.",
    "%s enter the database username." : "%s įrašykite duombazės naudotojo vardą.",
    "%s enter the database name." : "%s įrašykite duombazės pavadinimą.",
    "%s you may not use dots in the database name" : "%s negalite naudoti taškų duombazės pavadinime",
    "Oracle connection could not be established" : "Nepavyko sukurti Oracle ryšio",
    "Oracle username and/or password not valid" : "Neteisingas Oracle naudotojo vardas ir/arba slaptažodis",
    "DB Error: \"%s\"" : "DB klaida: \"%s\"",
    "Offending command was: \"%s\"" : "Vykdyta komanda buvo: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Turite prisijungti su egzistuojančia paskyra arba su administratoriumi.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Vykdyta komanda buvo: \"%s\", name: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "Neteisingas PostgreSQL naudotojo vardas ir/arba slaptažodis",
    "Set an admin username." : "Nustatyti administratoriaus naudotojo vardą.",
    "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
    "%s shared »%s« with you" : "%s pasidalino »%s« su tavimi",
    "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
    "Apps" : "Programos",
    "A valid username must be provided" : "Vartotojo vardas turi būti tinkamas",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "Storage not available" : "Saugykla nepasiekiama"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
